==> visual-dom-diff-0.2.0.tgz: package/lib/config.js <==
import { areNodesEqual, isDocument, isDocumentFragment, isElement, isText } from './util';
/**
 * The type of the result returned by the `compareNodes` option.
 */
export var CompareNodesResult;
(function (CompareNodesResult) {
    /**
     * Nodes are identical and should not be marked up in the diff result.
     */
    CompareNodesResult[CompareNodesResult["IDENTICAL"] = 0] = "IDENTICAL";
    /**
     * Nodes are similar and should be marked up in the diff result as modified.
     */
    CompareNodesResult[CompareNodesResult["SIMILAR"] = 1] = "SIMILAR";
    /**
     * Nodes are different and should be marked up in the diff result as a removal followed by an insertion.
     */
    CompareNodesResult[CompareNodesResult["DIFFERENT"] = 2] = "DIFFERENT";
})(CompareNodesResult || (CompareNodesResult = {}));
const skipChildrenMap = new Set();
skipChildrenMap.add('IMG');
skipChildrenMap.add('VIDEO');
skipChildrenMap.add('IFRAME');
skipChildrenMap.add('OBJECT');
skipChildrenMap.add('SVG');
const skipSelfMap = new Set();
skipSelfMap.add('BDO');
skipSelfMap.add('BDI');
skipSelfMap.add('Q');
skipSelfMap.add('CITE');
skipSelfMap.add('CODE');
skipSelfMap.add('DATA');
skipSelfMap.add('TIME');
skipSelfMap.add('VAR');
skipSelfMap.add('DFN');
skipSelfMap.add('ABBR');
skipSelfMap.add('STRONG');
skipSelfMap.add('EM');
skipSelfMap.add('BIG');
skipSelfMap.add('SMALL');
skipSelfMap.add('MARK');
skipSelfMap.add('SUB');
skipSelfMap.add('SUP');
skipSelfMap.add('SAMP');
skipSelfMap.add('KBD');
skipSelfMap.add('B');
skipSelfMap.add('I');
skipSelfMap.add('S');
skipSelfMap.add('U');
skipSelfMap.add('SPAN');
export function optionsToConfig({ addedClass = 'vdd-added', ignoreCase = false, modifiedClass = 'vdd-modified', removedClass = 'vdd-removed', skipChildren, skipSelf, compareNodes } = {}) {
    return {
        addedClass,
        ignoreCase,
        modifiedClass,
        removedClass,
        skipChildren(node) {
            if (!isElement(node) &&
                !isDocumentFragment(node) &&
                !isDocument(node)) {
                return true;
            }
            if (skipChildren) {
                const result = skipChildren(node);
                if (typeof result === 'boolean') {
                    return result;
                }
            }
            return skipChildrenMap.has(node.nodeName);
        },
        skipSelf(node) {
            if (!isText(node) && !isElement(node)) {
                return true;
            }
            if (skipSelf) {
                const result = skipSelf(node);
                if (typeof result === 'boolean') {
                    return result;
                }
            }
            return skipSelfMap.has(node.nodeName);
        },
        compareNodes(node1, node2) {
            if (compareNodes) {
                const result = compareNodes(node1, node2);
                if (result === CompareNodesResult.IDENTICAL ||
                    result === CompareNodesResult.SIMILAR ||
                    result === CompareNodesResult.DIFFERENT) {
                    return result;
                }
            }
            return areNodesEqual(node1, node2)
                ? CompareNodesResult.IDENTICAL
                : CompareNodesResult.DIFFERENT;
        }
    };
}

==> visual-dom-diff-0.3.0.tgz: package/lib/config.js <==
import { isDocument, isDocumentFragment, isElement, isText } from './util';
const skipChildrenMap = new Set();
skipChildrenMap.add('IMG');
skipChildrenMap.add('VIDEO');
skipChildrenMap.add('IFRAME');
skipChildrenMap.add('OBJECT');
skipChildrenMap.add('SVG');
const skipSelfMap = new Set();
skipSelfMap.add('BDO');
skipSelfMap.add('BDI');
skipSelfMap.add('Q');
skipSelfMap.add('CITE');
skipSelfMap.add('CODE');
skipSelfMap.add('DATA');
skipSelfMap.add('TIME');
skipSelfMap.add('VAR');
skipSelfMap.add('DFN');
skipSelfMap.add('ABBR');
skipSelfMap.add('STRONG');
skipSelfMap.add('EM');
skipSelfMap.add('BIG');
skipSelfMap.add('SMALL');
skipSelfMap.add('MARK');
skipSelfMap.add('SUB');
skipSelfMap.add('SUP');
skipSelfMap.add('SAMP');
skipSelfMap.add('KBD');
skipSelfMap.add('B');
skipSelfMap.add('I');
skipSelfMap.add('S');
skipSelfMap.add('U');
skipSelfMap.add('SPAN');
export function optionsToConfig({ addedClass = 'vdd-added', ignoreCase = false, modifiedClass = 'vdd-modified', removedClass = 'vdd-removed', skipChildren, skipSelf } = {}) {
    return {
        addedClass,
        ignoreCase,
        modifiedClass,
        removedClass,
        skipChildren(node) {
            if (!isElement(node) &&
                !isDocumentFragment(node) &&
                !isDocument(node)) {
                return true;
            }
            if (skipChildren) {
                const result = skipChildren(node);
                if (typeof result === 'boolean') {
                    return result;
                }
            }
            return skipChildrenMap.has(node.nodeName);
        },
        skipSelf(node) {
            if (!isText(node) && !isElement(node)) {
                return true;
            }
            if (skipSelf) {
                const result = skipSelf(node);
                if (typeof result === 'boolean') {
                    return result;
                }
            }
            return skipSelfMap.has(node.nodeName);
        }
    };
}
